@@ -46,10 +46,10 @@ class DescargaPadronesHistory(Base):
     padron = Column(String(100), nullable=False)
     periodo = Column(String(6), nullable=True)
 
-class AgipadronGeneral(Base):
+class AgipPadronGeneral(Base):
     """Agip Padron General"""
 
-    __tablename__ = "arba_padron_general_percepciones"
+    __tablename__ = "agip_padron_general"
     __table_args__ = ({"postgresql_partition_by": "LIST (periodo)"},)
    
     id = Column(Integer, primary_key=True, autoincrement=True)
